import {Component} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {forkJoin, Subscription} from 'rxjs';
import {Post} from '../../models/post';
import {PostService} from '../../services/post.service';
import {HeaderComponent} from '../../components/header/header.component';
import {DatePipe, JsonPipe} from '@angular/common';
import {CommentService} from '../../services/comment.service';
import {MessageService} from 'primeng/api';
import {Comment} from '../../models/comment';
import {AvatarModule} from 'primeng/avatar';

@Component({
  selector: 'app-post',
  standalone: true,
  imports: [
    HeaderComponent,
    DatePipe,
    JsonPipe,
    AvatarModule
  ],
  templateUrl: './post.component.html',
  styleUrl: './post.component.css'
})
export class PostComponent {
  subs: Subscription[] = [];
  comments: Comment[] = [];
  concernedPost: Post | undefined;

  constructor(private route: ActivatedRoute,
              private postService: PostService,
              private commentService: CommentService,
              private messageService: MessageService,) {
    this.route.paramMap.subscribe(params => {
      const postId = params.get('postId');
      if (postId) {
        this.subs.push(
          forkJoin({
          post: this.postService.getPost(BigInt(postId)),
          comment: this.commentService.list(BigInt(postId))
        }).subscribe({
            next: res => {
              this.concernedPost = res.post;
              this.comments = res.comment.sort((a, b) => {
                if (a.commentDate < b.commentDate) {
                  return -1
                } else if (a.commentDate > b.commentDate) {
                  return 1
                }
                return 0
              });
            },
            error: err => this.failureMessage("Erreur", err.message)
          }));
      }
    });
  }

  failureMessage(summary: string, detail: string): void {
    this.messageService.add({
      severity: 'error',
      summary: summary,
      detail: detail,
      life: 3000,
      closable: false
    });
  }
}
